@@ -32,17 +32,14 @@ def concat_spark_columns(data, name='concat_column', sep='|', return_data=False)
 	:param return_data: if True, the whole data frome with the new column is returned, otherwise just the column
 	:rtype: SparkDF
 	"""
-	string_columns = [col[0] for col in data.dtypes if col[1].startswith('string')]
 
-	data = data.withColumn(
-		name, f.concat_ws(
-			sep,
-			*[
-				f.col(col) if col in string_columns else f.lower(f.col(col).cast(StringType()))
-				for col in data.columns
-			]
-		)
-	)
+	@f.udf(StringType())
+	def _to_string(x):
+		if isinstance(x, dict):
+			x = dict(x)
+		return x if isinstance(x, str) else str(x).lower()
+
+	data = data.withColumn(name, f.concat_ws(sep, *[_to_string(col) for col in data.columns]))
 
 	if return_data:
 		return data
